==> bluedevil_5.12.8.orig.tar.xz: bluedevil-5.12.8/src/sendfile/pages/failpage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>                         *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef FAILPAGE_H
#define FAILPAGE_H

#include "ui_failpage.h"

#include <QWizardPage>

class SendFileWizard;

class FailPage : public QWizardPage, Ui::FailPage
{
    Q_OBJECT

public:
    explicit FailPage(SendFileWizard *parent = Q_NULLPTR);

    void initializePage() Q_DECL_OVERRIDE;

private:
    SendFileWizard *m_wizard;
};

#endif // FAILPAGE_H

==> bluedevil_5.18.4.1.orig.tar.xz: bluedevil-5.18.4.1/src/sendfile/pages/failpage.h <==
/*****************************************************************************
 * This file is part of the KDE project                                      *
 *                                                                           *
 * Copyright (C) 2015 David Rosca <nowrep@gmail.com>                         *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef FAILPAGE_H
#define FAILPAGE_H

#include "ui_failpage.h"

#include <QWizardPage>

class SendFileWizard;

class FailPage : public QWizardPage, Ui::FailPage
{
    Q_OBJECT

public:
    explicit FailPage(SendFileWizard *parent = nullptr);

    void initializePage() override;

private:
    SendFileWizard *m_wizard;
};

#endif // FAILPAGE_H
